@@ -6,6 +6,7 @@ from selenium.webdriver.common import keys
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.common.by import By as by
 from selenium.common.exceptions import NoSuchElementException
+from selenium.webdriver.firefox.options import Options as FirefoxOptions
 
 from fake_useragent import UserAgent
 import tldextract
@@ -20,17 +21,18 @@ RANDOM_USERAGENT = 'random'
 class Firefox:
     def __init__(
         self,
-        id: str,
+        cookies_folder_path: str,
+        extensions_folder_path: str,
         host: str = None,
         port: int = None,
         private: bool = False,
         full_screen: bool = True,
+        headless: bool = False,
         language: str = 'en-us',
         manual_set_timezone: bool = False,
         user_agent: str = None
     ):
-        self.id = id
-        cookies_folder_path = self.__cookies_folder_path(create_if_not_exists=True)
+        self.cookies_folder_path = cookies_folder_path
         profile = webdriver.FirefoxProfile()
 
         if user_agent is not None:
@@ -76,60 +78,69 @@ class Firefox:
 
         profile.update_preferences()
 
-        self.driver = webdriver.Firefox(firefox_profile=profile)
+        options = FirefoxOptions()
+        if headless:
+            options.add_argument("--headless")
+
+        self.driver = webdriver.Firefox(firefox_profile=profile, firefox_options=options)
 
         if full_screen:
             self.driver.fullscreen_window()
         
-        change_timezone_id = None
-        extensions_folder_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'resources/extensions')
-        for (dirpath, _, filenames) in os.walk(extensions_folder_path):
-            for filename in filenames:
-                if filename.endswith('.xpi') or filename.endswith('.zip'):
-                    addon_id = self.driver.install_addon(os.path.join(dirpath, filename), temporary=False)
+        try:
+            change_timezone_id = None
+            for (dirpath, _, filenames) in os.walk(extensions_folder_path):
+                for filename in filenames:
+                    if filename.endswith('.xpi') or filename.endswith('.zip'):
+                        addon_id = self.driver.install_addon(os.path.join(dirpath, filename), temporary=False)
 
-                    if 'change_timezone' in filename:
-                        change_timezone_id = addon_id
+                        if 'change_timezone' in filename:
+                            change_timezone_id = addon_id
         
-        self.driver.get("about:addons")
-        self.driver.find_element_by_id("category-extension").click()
-        self.driver.execute_script("""
-            let hb = document.getElementById("html-view-browser");
-            let al = hb.contentWindow.window.document.getElementsByTagName("addon-list")[0];
-            let cards = al.getElementsByTagName("addon-card");
-            for(let card of cards){
-                card.addon.disable();
-                card.addon.enable();
-            }
-        """)
+            # self.driver.get("about:addons")
+            # self.driver.find_element_by_id("category-extension").click()
+            # self.driver.execute_script("""
+            #     let hb = document.getElementById("html-view-browser");
+            #     let al = hb.contentWindow.window.document.getElementsByTagName("addon-list")[0];
+            #     let cards = al.getElementsByTagName("addon-card");
+            #     for(let card of cards){
+            #         card.addon.disable();
+            #         card.addon.enable();
+            #     }
+            # """)
 
-        while len(self.driver.window_handles) > 1:
-            time.sleep(0.5)
-            self.driver.switch_to.window(self.driver.window_handles[-1])
-            self.driver.close()
-        
-        self.driver.switch_to.window(self.driver.window_handles[0])
-
-        if change_timezone_id is not None and manual_set_timezone:
-            if host is not None and port is not None:
-                self.open_new_tab('https://whatismyipaddress.com/')
-                time.sleep(0.25)
-
-            self.open_new_tab('https://www.google.com/search?client=firefox-b-d&q=my+timezone')
-            time.sleep(0.25)
-
-            self.driver.switch_to.window(self.driver.window_handles[0])
-            
-            input('\n\n\nSet timezone.\n\nPress ENTER, when finished. ')
-        
             while len(self.driver.window_handles) > 1:
                 time.sleep(0.5)
                 self.driver.switch_to.window(self.driver.window_handles[-1])
                 self.driver.close()
             
             self.driver.switch_to.window(self.driver.window_handles[0])
-        elif host is not None and port is not None:
-            self.driver.get('https://whatismyipaddress.com/')
+
+            if change_timezone_id is not None and manual_set_timezone:
+                if host is not None and port is not None:
+                    self.open_new_tab('https://whatismyipaddress.com/')
+                    time.sleep(0.25)
+
+                self.open_new_tab('https://www.google.com/search?client=firefox-b-d&q=my+timezone')
+                time.sleep(0.25)
+
+                self.driver.switch_to.window(self.driver.window_handles[0])
+                
+                input('\n\n\nSet timezone.\n\nPress ENTER, when finished. ')
+            
+                while len(self.driver.window_handles) > 1:
+                    time.sleep(0.5)
+                    self.driver.switch_to.window(self.driver.window_handles[-1])
+                    self.driver.close()
+                
+                self.driver.switch_to.window(self.driver.window_handles[0])
+            elif host is not None and port is not None:
+                self.driver.get('https://whatismyipaddress.com/')
+        except:
+            while len(self.driver.window_handles) > 1:
+                time.sleep(0.5)
+                self.driver.switch_to.window(self.driver.window_handles[-1])
+                self.driver.close()
     
     def get(
         self,
@@ -265,23 +276,11 @@ class Firefox:
             except:
                 pass
 
-    def __cookies_folder_path(self, create_if_not_exists: bool = True) -> str:
-        path = os.path.join(
-            os.path.dirname(os.path.realpath(__file__)),
-            'resources/cookies',
-            self.id.replace('/', '_').replace(' ', '_').replace(':', '_')
-        )
-
-        if create_if_not_exists and not os.path.exists(path):
-            os.makedirs(path, exist_ok=True)
-        
-        return path
-
     def __cookies_path(self, create_folder_if_not_exists: bool = True) -> str:
         url_comps = tldextract.extract(self.driver.current_url)
         formatted_url = url_comps.domain + '.' + url_comps.suffix
 
         return os.path.join(
-            self.__cookies_folder_path(create_if_not_exists=create_folder_if_not_exists),
+            self.cookies_folder_path,
             formatted_url + '.pkl'
         )
\ No newline at end of file
